/*
 Storybook: Open Source software for novelists and authors.
 Copyright (C) 2008 - 2012 Martin Mustun

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package i18n;

import java.io.BufferedInputStream;
import java.io.BufferedWriter;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import java.nio.file.Files;
import javax.swing.JOptionPane;

/**
 * @author martin
 *
 */
public class IOTools {

	public static String cleanupFilename(String paramString) {
		String str = paramString.replaceAll("[\\/:*?\"<>|]", "");
		str = str.replaceAll("\\\\", "");
		return str;
	}

	public static String readFileAsString(String filePath) throws java.io.IOException {
		byte[] buffer = new byte[(int) new File(filePath).length()];
		BufferedInputStream f = null;
		try {
			f = new BufferedInputStream(new FileInputStream(filePath));
			f.read(buffer);
		} finally {
			if (f != null) {
				try {
					f.close();
				} catch (IOException e) {
					e.printStackTrace(System.err);
				}
			}
		}
		return new String(buffer);
	}

	public static void writeFileFromString(File file, String str) {
		try {
			file.createNewFile();
			try (BufferedWriter f = new BufferedWriter(new FileWriter(file))) {
				f.write(str, 0, str.length());
			}
		} catch (IOException e) {
			e.printStackTrace(System.err);
		}
	}

	public static InputStream stringToInputStream(String str) {
		return new ByteArrayInputStream(str.getBytes());
	}
	
	public static String convertToRrelativePath(String str, String path) {
		String rc=str.replace("file://"+path+File.pathSeparator, "");
		return(rc);
	}
	
	public static File selectDirectory(JDialog parent, String f) {
		JFileChooser chooser = new JFileChooser(f);
		chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
		chooser.setDialogTitle("Select a directory");
		chooser.setApproveButtonText("Select");
		int i = chooser.showOpenDialog(parent);
		if (i != 0) return(null);
		return chooser.getSelectedFile();
	}

	public static File selectFile(JDialog parent, String filename, String ext, String filter) {
		JFileChooser chooser = new JFileChooser(filename);
		chooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
		FileFilter fileFilter=new FileFilter(ext,filter);
		chooser.setDialogTitle("Select a file name");
		chooser.setApproveButtonText("Select");
		chooser.addChoosableFileFilter(fileFilter);
		chooser.setFileFilter(fileFilter);
		chooser.setSelectedFile(new File(filename));
		int i = chooser.showOpenDialog(parent);
		if (i != 0) return(null);
		return(chooser.getSelectedFile());
	}

}
